{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    sops-nix = {
      url = "github:Mic92/sops-nix";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };
  outputs = { nixpkgs, sops-nix, ... }: {
    colmena = {
      meta = {
        nixpkgs = import nixpkgs {
          system = "x86_64-linux";
          overlays = [ (final: prev: import ./packages final prev) ];
        };
      };

      defaults = { config, lib, name, ... }: {
        imports = [
          (./. + "/hosts/${name}/configuration.nix")
          ./modules
          ./common
          sops-nix.nixosModules.sops
        ];

        deployment.targetUser = null;
      };

      dns = { config, pkgs, ... }: {
        deployment.targetHost = "dns.bula22.de";
      };

      monitoring = { config, pkgs, ... }: {
        deployment.targetHost = "monitoring.bula22.de";
      };

      nixdeploy = {...}: {
        deployment.targetHost = "nixdeploy.bula22.de";
        deployment.allowLocalDeployment = true;
      };

      nerd = { ... }: {
        deployment.targetHost = "nerd.bula22.de";
        deployment.tags = [ "dect" ];
      };

      yate = { ... }: {
        deployment.targetHost = "yate.bula22.de";
        deployment.tags = [ "dect" "yate" ];
      };

      yate-dialup = { ... }: {
        deployment.targetHost = "yate-dialup.bula22.de";
        deployment.tags = [ "dect" "yate" ];
      };

      pre-router = { config, pkgs, ... }: {
        deployment.targetHost = "fd00:10:42:10::25";
        deployment.keys = {

        };
      };

      radius = { config, pkgs, ... }: {
        deployment.targetHost = "radius.bula22.de";
      };

      router = { config, pkgs, ... }: {
        deployment.targetHost = "router.bula22.de";
      };
    };
  };
}
