{ config, pkgs, lib, ... }:
with lib;

{
  imports =
    [
      ./hardware-configuration.nix
    ];
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "radius";
  networking.useDHCP = false;
  networking.interfaces.ens18.ipv4.addresses = [
    {address = "10.42.10.5"; prefixLength = 24; }
  ];
  networking.interfaces.ens18.ipv6.addresses = [
    {address = "2a01:4f8:1c0c:8221::5"; prefixLength = 64; }
  ];
  networking.defaultGateway = { address = "10.42.10.1"; interface = "ens18"; };
  networking.defaultGateway6 = { address = "2a01:4f8:1c0c:8221::1"; interface = "ens18"; };

  services.prometheus.exporters.node = {
    enable = true;
    listenAddress = "10.42.10.5";
    openFirewall = true;
  };

  services.freeradius.enable = true;
  services.freeradius.debug = true;
  users.users.radius.group = "radius";
  users.groups.radius = {};

  networking.firewall.allowedUDPPorts = [ 1812 ];

  environment.systemPackages = [ pkgs.eapol_test ];

  system.stateVersion = "22.05";
}
