{ config, pkgs, ...}:

{
  networking.vlans."net-zoll" = {
    id = 204;
    interface = "ens18";
  };

  networking.interfaces.net-zoll.ipv6.addresses = [
    { address = "fe80::1"; prefixLength = 64; }
    { address = "fd00:10:42:204::1"; prefixLength = 64; }
  ];
  networking.interfaces.net-zoll.ipv4.addresses = [
    { address = "10.42.204.1"; prefixLength = 24; }
  ];

  services.radvd.config = ''
    interface net-zoll {
      AdvSendAdvert on;
      MaxRtrAdvInterval 30;
      prefix ::/64 {
        AdvValidLifetime 60;
        AdvPreferredLifetime 30;
      };
      RDNSS 2a01:4f8:1c0c:8221::8 {};
      DNSSL bula22.de {};
    };
  '';

  services.kea.dhcp4 = {
    settings = {
      interfaces-config = {
        interfaces = [ "net-zoll" ];
      };
      subnet4 = [
        {
          id = 204;
          subnet = "10.42.204.1/24";
          pools = [
            {
              pool = "10.42.204.100 - 10.42.204.240";
            }
          ];
          option-data = [
            {
              name = "routers";
              data = "10.42.204.1";
            }
          ];
        }
      ];
    };
  };

  clerie.forward-filter.interfaces.net-zoll.rules = [
    { incomingInterface = "net-ikt"; }
  ];

  clerie.uplink-selector.interfaces.net-zoll.uplink = "uplink-a";
}
